import 'package:cims_apps/application/assets/path_assets.dart';
import 'package:cims_apps/application/component/button/button_back.dart';
import 'package:cims_apps/application/component/button/button_view.dart';
import 'package:cims_apps/application/component/image/image_view.dart';
import 'package:cims_apps/application/theme/color_palette.dart';
import 'package:cims_apps/core/route/route.dart';
import 'package:cims_apps/core/utils/size_config.dart';
import 'package:cims_apps/features/auth/registration/view/registration_password_view.dart';
import 'package:cims_apps/features/auth/registration/view/risk_profile/risk_profile_view_model/risk_profile_view_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class ResultsView extends StatelessWidget {
  final String totalScore;
  final RiskProfileResult typeResult;
  const ResultsView({super.key, required this.typeResult, required this.totalScore});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        toolbarHeight: 70,
        backgroundColor: Colors.white,
        surfaceTintColor: Colors.white,
        automaticallyImplyLeading: false,
        title: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            ButtonBack(),
            const Text('Risk Profile', textAlign: TextAlign.center),
            SizedBox(
                width: SizeConfig.width * 0.1
            )
          ],
        ),
        shape: const RoundedRectangleBorder(
            side: BorderSide(color: ColorPalette.slate200)
        ),
      ),
      body: SingleChildScrollView(
        padding: EdgeInsets.all(24),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            ClipRRect(
              borderRadius: BorderRadius.circular(8),
              child: Container(
                decoration: BoxDecoration(
                  color: typeResult.color,
                  image: DecorationImage(image: AssetImage(typeResult.img), alignment: Alignment.centerRight)
                ),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Container(
                      padding: EdgeInsets.all(24),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            typeResult.type,
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 24,
                              color: ColorPalette.white
                            ),
                          ),
                          SizedBox(height: 16,),
                          Text('Total Score :',
                            style: TextStyle(
                                fontWeight: FontWeight.bold,
                                fontSize: 16,
                                color: ColorPalette.white
                            ),
                          ),
                          Text(totalScore,
                            style: TextStyle(
                                fontWeight: FontWeight.bold,
                                fontSize: 28,
                                color: ColorPalette.white
                            ),
                          )
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
            SizedBox(
              height: 24,
            ),
            Text(
              typeResult.desc,
              style: TextStyle(
                color: ColorPalette.slate500,
                fontSize: 16
              )
            ),
            SizedBox(
              height: 24,
            ),
            Text(
              'Suitable Product',
              style: TextStyle(
                color: ColorPalette.slate800,
                fontWeight: FontWeight.bold,
                fontSize: 16
              ),
            ),
            SizedBox(
              height: 16,
            ),
            Wrap(
              runSpacing: 16,
              children: typeResult.suitableProduct.map((e) {
                return Container(
                  padding: EdgeInsets.all(16),
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(6),
                    border: Border.all(color: ColorPalette.slate200),
                  ),
                  child: Row(
                    children: [
                      Container(
                        padding: EdgeInsets.all(8),
                        alignment: Alignment.center,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: typeResult.color.withOpacity(0.1)
                        ),
                        child: Image.asset(e['icon'], width: SizeConfig.width * 0.07, color: typeResult.color)
                      ),
                      SizedBox(
                        width: 12,
                      ),
                      Expanded(
                        child: Text(e['desc'],
                          style: TextStyle(
                            fontSize: 16,
                            fontWeight: FontWeight.bold,
                            color: ColorPalette.slate800
                          ),
                        ),
                      )
                    ],
                  ),
                );
              }).toList(),
            ),
            SizedBox(
              height: 32,
            ),
            ButtonView(
              name: 'Re-test',
              onPressed: () {
              },
              marginVertical: 0,
              backgroundColor: ColorPalette.white,
              textColor: ColorPalette.primary,
              borderColor: ColorPalette.primary,
              isOutlined: true,
              textSize: 16,
              heightWrapContent: true,
              contentPadding: EdgeInsets.all(16),
              width: SizeConfig.width,
            ),
            SizedBox(
              height: 16,
            ),
            ButtonView(
              name: 'Confirm',
              onPressed: () {
                routePush(context, page: DialogSuccess());
              },
              marginVertical: 0,
              textSize: 16,
              heightWrapContent: true,
              contentPadding: EdgeInsets.all(16),
              width: SizeConfig.width,
            )
          ],
        ),
      ),
    );
  }
}
