import 'package:cims_apps/application/assets/path_assets.dart';
import 'package:cims_apps/application/component/button/button_view.dart';
import 'package:cims_apps/application/component/image/image_view.dart';
import 'package:cims_apps/application/theme/color_palette.dart';
import 'package:cims_apps/core/route/route.dart';
import 'package:cims_apps/core/utils/size_config.dart';
import 'package:cims_apps/features/auth/login/view/login_view.dart';
import 'package:cims_apps/features/auth/registration/view/registration_view.dart';
import 'package:cims_apps/features/bottom_navigation_view.dart';
import 'package:flutter/material.dart';

class DashboardPublicView extends StatelessWidget {
  static const routeName = '/DashboardPublicView';
  const DashboardPublicView({Key? key}) : super(key: key);

  Widget _caption() {
    return Column(
      children: [
        const Text(
          'Welcome!',
          style: TextStyle(
              color: ColorPalette.primary,
              fontWeight: FontWeight.w700,
              fontSize: 28),
        ),
        SizedBox(
          width: SizeConfig.width * .8,
          child: const Text(
            'We serve the management of Third Party investment funds in fulfilling financial goals.',
            textAlign: TextAlign.center,
            style: TextStyle(color: ColorPalette.greyFont),
          ),
        ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        padding: const EdgeInsets.symmetric(
          vertical: 32.0,
          horizontal: 24.0,
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            ImageView(
              image: PathAssets.icon1,
              width: SizeConfig.width * .35,
            ),
            Align(
                alignment: Alignment.center,
                heightFactor: 1,
                child: _caption()),
            Align(
              alignment: Alignment.center,
              child: ImageView(
                image: PathAssets.imgDashboard,
                width: SizeConfig.width * .7,
              ),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                ButtonView(
                  name: 'Sign in',
                  isOutlined: true,
                  width: SizeConfig.width * .43,
                  height: SizeConfig.height * .06,
                  onPressed: () {
                    routePush(context, page: const LoginView());
                  },
                ),
                ButtonView(
                  name: 'Sign Up',
                  width: SizeConfig.width * .43,
                  height: SizeConfig.height * .06,
                  onPressed: () {
                    routePush(context, page: const RegistrationView());
                  },
                ),
              ],
            ),
            const ImageView(image: PathAssets.iconConnect),
            ButtonView(
              name: 'Google',
              isSecondaryColor: true,
              isOutlined: true,
              prefixIcon: const ImageView(
                image: PathAssets.iconGoogle,
                width: 26,
              ),
              onPressed: () {},
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                ImageView(
                  image: PathAssets.iconOjk,
                  width: SizeConfig.width * .20,
                ),
                ImageView(
                  image: PathAssets.iconInklusi,
                  width: SizeConfig.width * .20,
                ),
                ImageView(
                  image: PathAssets.iconReksadana,
                  width: SizeConfig.width * .20,
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
